load_ns

Function load_ns 

pub fn load_ns(
    globals: Arc<GlobalEnv>,
    spec: &RequireSpec,
    current_ns: &str,
) -> Result<(), EvalError>
Find, load, and wire up the source file for spec.ns.

  • Idempotent: if already loaded, skips file evaluation but still applies alias/refer in the current namespace.
  • Cycle detection: returns an error if spec.ns is currently being loaded.