pub fn load_ns(
globals: Arc<GlobalEnv>,
spec: &RequireSpec,
current_ns: &str,
) -> Result<(), EvalError>Expand description
Find, load, and wire up the source file for spec.ns.
- Idempotent: if already loaded, skips file evaluation but still applies alias/refer in the current namespace.
- Cycle detection: returns an error if
spec.nsis currently being loaded.